/*
 * Copyright (c) ROSA Laboratory 2011
 * License: GPLv3
 *
 * Authors:
 *   Julia Mineeva <julia.mineeva@osinit.ru>
 *   Evgeniy Augin <evgeniy.augin@osinit.ru>
 *   Ivan Kulkov   <ivan.kulkov@osinit.ru>
 *
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as
 *   published by the Free Software Foundation; either version 3,
 *   or (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details
 *
 *   You should have received a copy of the GNU General Public
 *   License along with this program; if not, write to the
 *   Free Software Foundation, Inc.,
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
#ifndef __timeslider_h_
#define __timeslider_h_

/*
 * Description of class TimeSlider
 */

#include <QGraphicsWidget>
#include <QStringList>
#include <Plasma/Slider>
//#include <Plasma/Label>
#include <plasma/widgets/label.h>
#include <plasma/widgets/toolbutton.h>

#include "activityeventssource.h"
#include "timeframeslider.h"

class QGraphicsLinearLayout;
class QGraphicsItem;

enum sliderMode{
    DAY_MODE,
    MONTH_MODE
};

class QTimeSlider : public QGraphicsWidget
{
  Q_OBJECT
  
public:
  QTimeSlider(QGraphicsItem* parent = 0, Qt::WindowFlags wFlags = 0);
  virtual ~QTimeSlider();

  void setPeriod(EventPeriod* period);
  EventPeriod getPeriod() const { return m_period; };

  int periodToValue(const EventPeriod* period);
  EventPeriod valueToPeriod(int val);

  void paint(QPainter *painter, const QStyleOptionGraphicsItem *,QWidget *);


protected:
  //void createMonthLayout(QGraphicsLinearLayout*);

protected slots:
  void sliderChanged(int value);
  void updatePeriodLabel();

public slots:
  void leftButtonSlot();
  void rightButtonSlot();
  void dayButtonSlot();
  void monthButtonSlot();


signals:
  void periodChanged(EventPeriod* period);

protected:
  QStringList            m_monthList;
  QGraphicsLinearLayout* m_layout;
  EventPeriod            m_period;
  sliderMode             m_mode;
  //Plasma::Slider*        m_slider;
  TimeFrameSlider*       m_slider;
  Plasma::Label*         m_labelSlider;
  Plasma::ToolButton*    m_leftButton;
  Plasma::ToolButton*    m_rightButton;
  Plasma::ToolButton*    m_dayButton;
  Plasma::ToolButton*    m_monthButton;
};



#endif // __timeslider_h_
